@@ -34,6 +34,7 @@
 #include <glib-object.h>
 #include <time.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <libgnome-desktop/gnome-desktop-version.h>
 
 G_BEGIN_DECLS
 
@@ -47,7 +48,7 @@ typedef enum {
 #define GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY		(gnome_desktop_thumbnail_factory_get_type ())
 #define GNOME_DESKTOP_THUMBNAIL_FACTORY(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY, GnomeDesktopThumbnailFactory))
 #define GNOME_DESKTOP_THUMBNAIL_FACTORY_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY, GnomeDesktopThumbnailFactoryClass))
-#define GNOME_DESKTOP_IS_THUMBNAIL_FACTORY(obj)		(G_TYPE_INSTANCE_CHECK_TYPE ((obj), GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY))
+#define GNOME_DESKTOP_IS_THUMBNAIL_FACTORY(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY))
 #define GNOME_DESKTOP_IS_THUMBNAIL_FACTORY_CLASS(klass)	(G_TYPE_CLASS_CHECK_CLASS_TYPE ((klass), GNOME_DESKTOP_TYPE_THUMBNAIL_FACTORY))
 
 typedef struct _GnomeDesktopThumbnailFactory        GnomeDesktopThumbnailFactory;
@@ -80,16 +81,22 @@ gboolean               gnome_desktop_thumbnail_factory_can_thumbnail (GnomeDeskt
 								      const char            *uri,
 								      const char            *mime_type,
 								      time_t                 mtime);
-GdkPixbuf *            gnome_desktop_thumbnail_factory_generate_thumbnail (GnomeDesktopThumbnailFactory *factory,
-									   const char            *uri,
-									   const char            *mime_type);
-void                   gnome_desktop_thumbnail_factory_save_thumbnail (GnomeDesktopThumbnailFactory *factory,
-								       GdkPixbuf             *thumbnail,
-								       const char            *uri,
-								       time_t                 original_mtime);
-void                   gnome_desktop_thumbnail_factory_create_failed_thumbnail (GnomeDesktopThumbnailFactory *factory,
-										const char            *uri,
-										time_t                 mtime);
+GdkPixbuf * gnome_desktop_thumbnail_factory_generate_thumbnail (GnomeDesktopThumbnailFactory *factory,
+                                                                const char                   *uri,
+                                                                const char                   *mime_type,
+                                                                GCancellable                 *cancellable,
+                                                                GError                      **error);
+gboolean               gnome_desktop_thumbnail_factory_save_thumbnail (GnomeDesktopThumbnailFactory *factory,
+                                                                       GdkPixbuf                    *thumbnail,
+                                                                       const char                   *uri,
+                                                                       time_t                        original_mtime,
+                                                                       GCancellable                 *cancellable,
+                                                                       GError                      **error);
+gboolean               gnome_desktop_thumbnail_factory_create_failed_thumbnail (GnomeDesktopThumbnailFactory *factory,
+                                                                                const char                   *uri,
+                                                                                time_t                        mtime,
+                                                                                GCancellable                 *cancellable,
+                                                                                GError                      **error);
 
 void                   gnome_desktop_thumbnail_factory_generate_thumbnail_async (GnomeDesktopThumbnailFactory *factory,
                                                                                  const char                   *uri,
@@ -110,7 +117,7 @@ void                   gnome_desktop_thumbnail_factory_save_thumbnail_async (Gno
                                                                              GAsyncReadyCallback           callback,
                                                                              gpointer                      user_data);
 
-void                   gnome_desktop_thumbnail_factory_save_thumbnail_finish (GnomeDesktopThumbnailFactory *factory,
+gboolean               gnome_desktop_thumbnail_factory_save_thumbnail_finish (GnomeDesktopThumbnailFactory *factory,
                                                                               GAsyncResult                 *result,
                                                                               GError                      **error);
 
@@ -121,7 +128,7 @@ void                   gnome_desktop_thumbnail_factory_create_failed_thumbnail_a
                                                                                       GAsyncReadyCallback           callback,
                                                                                       gpointer                      user_data);
 
-void                   gnome_desktop_thumbnail_factory_create_failed_thumbnail_finish (GnomeDesktopThumbnailFactory *factory,
+gboolean               gnome_desktop_thumbnail_factory_create_failed_thumbnail_finish (GnomeDesktopThumbnailFactory *factory,
                                                                                        GAsyncResult                 *result,
                                                                                        GError                      **error);
 
