@@ -32,6 +32,7 @@
 
 #include <gio/gio.h>
 #include <gdesktop-enums.h>
+#include <libgnome-desktop/gnome-desktop-version.h>
 
 G_BEGIN_DECLS
 
@@ -58,6 +59,8 @@ struct _GnomeWallClockClass
 	GObjectClass parent_class;
 };
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GnomeWallClock, g_object_unref)
+
 GType             gnome_wall_clock_get_type      (void);
 
 GnomeWallClock *  gnome_wall_clock_new           (void);
